==> metrics-collector-container-v2.2.10-3.tar.gz: metrics-collector-container-v2.2.10-3/app/pkg/authorize/tollbooth/tollbooth.go <==
package tollbooth

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io/ioutil"
	"mime"
	"net/http"
	"net/url"

	"github.com/go-kit/kit/log"
	"github.com/pkg/errors"

	"github.com/open-cluster-management/metrics-collector/pkg/authorize"
	"github.com/open-cluster-management/metrics-collector/pkg/logger"
)

type clusterRegistration struct {
	ClusterID          string `json:"cluster_id"`
	AuthorizationToken string `json:"authorization_token"`
	AccountID          string `json:"account_id"`
}

type registrationError struct {
	Name   string `json:"name"`
	Reason string `json:"reason"`
}

type authorizer struct {
	to     *url.URL
	client *http.Client
	logger log.Logger
}

func NewAuthorizer(logger log.Logger, c *http.Client, to *url.URL) *authorizer {
	return &authorizer{
		to:     to,
		client: c,
		logger: log.With(logger, "component", "authorize/toolbooth"),
	}
}

func (a *authorizer) AuthorizeCluster(token, cluster string) (string, error) {
	regReq := &clusterRegistration{
		ClusterID:          cluster,
		AuthorizationToken: token,
	}

	data, err := json.Marshal(regReq)
	if err != nil {
		return "", err
	}

	body, err := authorize.AgainstEndpoint(a.logger, a.client, a.to, data, cluster, func(res *http.Response) error {
		contentType := res.Header.Get("Content-Type")
		mediaType, _, err := mime.ParseMediaType(contentType)
		if err != nil || mediaType != "application/json" {
			logger.Log(a.logger, logger.Warn, "msg",
				"upstream server responded with an unknown content type", "to",
				a.to, "contenttype", contentType)
			return fmt.Errorf("unrecognized token response content-type %q", contentType)
		}
		return nil
	})
	if err != nil {
		return "", err
	}

	response := &clusterRegistration{}
	if err := json.Unmarshal(body, response); err != nil {
		logger.Log(a.logger, logger.Warn, "msg", "upstream server response could not be parsed", "to", a.to)
		return "", fmt.Errorf("unable to parse response body: %v", err)
	}

	if len(response.AccountID) == 0 {
		logger.Log(a.logger, logger.Warn, "msg", "upstream server responded with an empty user string", "to", a.to)
		return "", fmt.Errorf("server responded with an empty user string")
	}

	return response.AccountID, nil
}

// ExtractToken extracts the token from an auth request.
// In the case of a request to Tollbooth, the token
// is the entire contents of the request body.
func ExtractToken(r *http.Request) (string, error) {
	body, err := ioutil.ReadAll(r.Body)
	if err := r.Body.Close(); err != nil {
		return "", errors.Wrap(err, "failed to close body")
	}
	r.Body = ioutil.NopCloser(bytes.NewBuffer(body))
	return string(body), err
}

==> metrics-collector-container-v2.2.11-5.tar.gz: metrics-collector-container-v2.2.11-5/app/pkg/authorize/tollbooth/tollbooth.go <==
package tollbooth

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io/ioutil"
	"mime"
	"net/http"
	"net/url"

	"github.com/go-kit/kit/log"
	"github.com/pkg/errors"

	"github.com/stolostron/metrics-collector/pkg/authorize"
	"github.com/stolostron/metrics-collector/pkg/logger"
)

type clusterRegistration struct {
	ClusterID          string `json:"cluster_id"`
	AuthorizationToken string `json:"authorization_token"`
	AccountID          string `json:"account_id"`
}

type registrationError struct {
	Name   string `json:"name"`
	Reason string `json:"reason"`
}

type authorizer struct {
	to     *url.URL
	client *http.Client
	logger log.Logger
}

func NewAuthorizer(logger log.Logger, c *http.Client, to *url.URL) *authorizer {
	return &authorizer{
		to:     to,
		client: c,
		logger: log.With(logger, "component", "authorize/toolbooth"),
	}
}

func (a *authorizer) AuthorizeCluster(token, cluster string) (string, error) {
	regReq := &clusterRegistration{
		ClusterID:          cluster,
		AuthorizationToken: token,
	}

	data, err := json.Marshal(regReq)
	if err != nil {
		return "", err
	}

	body, err := authorize.AgainstEndpoint(a.logger, a.client, a.to, data, cluster, func(res *http.Response) error {
		contentType := res.Header.Get("Content-Type")
		mediaType, _, err := mime.ParseMediaType(contentType)
		if err != nil || mediaType != "application/json" {
			logger.Log(a.logger, logger.Warn, "msg",
				"upstream server responded with an unknown content type", "to",
				a.to, "contenttype", contentType)
			return fmt.Errorf("unrecognized token response content-type %q", contentType)
		}
		return nil
	})
	if err != nil {
		return "", err
	}

	response := &clusterRegistration{}
	if err := json.Unmarshal(body, response); err != nil {
		logger.Log(a.logger, logger.Warn, "msg", "upstream server response could not be parsed", "to", a.to)
		return "", fmt.Errorf("unable to parse response body: %v", err)
	}

	if len(response.AccountID) == 0 {
		logger.Log(a.logger, logger.Warn, "msg", "upstream server responded with an empty user string", "to", a.to)
		return "", fmt.Errorf("server responded with an empty user string")
	}

	return response.AccountID, nil
}

// ExtractToken extracts the token from an auth request.
// In the case of a request to Tollbooth, the token
// is the entire contents of the request body.
func ExtractToken(r *http.Request) (string, error) {
	body, err := ioutil.ReadAll(r.Body)
	if err := r.Body.Close(); err != nil {
		return "", errors.Wrap(err, "failed to close body")
	}
	r.Body = ioutil.NopCloser(bytes.NewBuffer(body))
	return string(body), err
}
